@@ -6,7 +6,7 @@ Kafka::Connection - Object interface to connect to a kafka cluster.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::Connection> version 1.001001 .
+This documentation refers to C<Kafka::Connection> version 1.001011 .
 
 =cut
 
@@ -20,7 +20,7 @@ use warnings;
 
 our $DEBUG = 0;
 
-our $VERSION = '1.001001';
+our $VERSION = '1.001011';
 
 use Exporter qw(
     import
@@ -42,7 +42,6 @@ use Data::Validate::IP qw(
 );
 use Const::Fast;
 use List::Util qw(
-    all
     shuffle
 );
 use Params::Util qw(
@@ -1219,7 +1218,7 @@ sub _connectIO {
 
     my $server_data = $self->{_IO_cache}->{ $server };
     my $io;
-    unless ( $server_data && ( $io = $server_data->{IO} ) && $io->is_alive ) {
+    unless ( $server_data && ( $io = $server_data->{IO} ) ) {
         try {
             $server_data->{IO} = Kafka::IO->new(
                 host        => $server_data->{host},
