@@ -6,7 +6,7 @@ Kafka::Producer - Perl interface for Kafka producer client.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::Producer> version 1.001001 .
+This documentation refers to C<Kafka::Producer> version 1.001011 .
 
 =cut
 
@@ -18,7 +18,7 @@ use warnings;
 
 # ENVIRONMENT ------------------------------------------------------------------
 
-our $VERSION = '1.001001';
+our $VERSION = '1.001011';
 
 #-- load the modules -----------------------------------------------------------
 
@@ -306,7 +306,7 @@ Supported codecs:
 C<$COMPRESSION_NONE>,
 C<$COMPRESSION_GZIP>,
 C<$COMPRESSION_SNAPPY>.
-(the defaults that can be imported from the L<Kafka|Kafka> module.
+The defaults that can be imported from the L<Kafka|Kafka> module.
 
 =back
 
